@@ -76,6 +76,7 @@ import org.videolan.medialibrary.Tools;
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.medialibrary.media.SearchAggregate;
+import org.videolan.vlc.extensions.ExtensionsManager;
 import org.videolan.vlc.gui.AudioPlayerContainerActivity;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.BitmapUtil;
@@ -135,6 +136,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     public static final String ACTION_REMOTE_LAST_VIDEO_PLAYLIST = ACTION_REMOTE_GENERIC+"LastVideoPlaylist";
     public static final String ACTION_REMOTE_SWITCH_VIDEO = ACTION_REMOTE_GENERIC+"SwitchToVideo";
     public static final String ACTION_PLAY_FROM_SEARCH = ACTION_REMOTE_GENERIC+"play_from_search";
+    public static final String ACTION_CAR_MODE_EXIT = "android.app.action.EXIT_CAR_MODE";
 
     public static final String EXTRA_SEARCH_BUNDLE = ACTION_REMOTE_GENERIC+"extra_search_bundle";
 
@@ -252,7 +254,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         }
 
         mMedialibrary = VLCApplication.getMLInstance();
-        if (!AndroidDevices.hasTsp() && !AndroidDevices.hasPlayServices())
+        if (!AndroidDevices.hasTsp && !AndroidDevices.hasPlayServices)
             AndroidDevices.setRemoteControlReceiverEnabled(true);
 
         mDetectHeadset = mSettings.getBoolean("enable_headset_detection", true);
@@ -282,6 +284,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         filter.addAction(Intent.ACTION_HEADSET_PLUG);
         filter.addAction(AudioManager.ACTION_AUDIO_BECOMING_NOISY);
         filter.addAction(VLCApplication.SLEEP_INTENT);
+        filter.addAction(ACTION_CAR_MODE_EXIT);
         registerReceiver(mReceiver, filter);
 
         boolean stealRemoteControl = mSettings.getBoolean("enable_steal_remote_control", false);
@@ -343,7 +346,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             mMediaSession = null;
         }
 
-        if (!AndroidDevices.hasTsp() && !AndroidDevices.hasPlayServices())
+        if (!AndroidDevices.hasTsp && !AndroidDevices.hasPlayServices)
             AndroidDevices.setRemoteControlReceiverEnabled(false);
 
         if (mWakeLock.isHeld())
@@ -505,7 +508,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                     if (wasPlaying && hasCurrentMedia() && mSettings.getBoolean("enable_play_on_headset_insertion", false))
                         play();
                 }
-            }
+            } else if (action.equalsIgnoreCase(ACTION_CAR_MODE_EXIT))
+                BrowserProvider.unbindExtensionConnection();
         }
     };
 
@@ -580,10 +584,13 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         public void onEvent(MediaPlayer.Event event) {
             switch (event.type) {
                 case MediaPlayer.Event.Playing:
+                    mStopped = false;
                     loadMediaMeta();
-                    if (mSavedTime > 0L)
-                        seek(mSavedTime);
-                    mSavedTime = 0L;
+                    if (mSavedTime > 0L) {
+                        if (mSavedTime < 0.95*getLength())
+                            seek(mSavedTime);
+                        mSavedTime = 0L;
+                    }
 
                     Log.i(TAG, "MediaPlayer.Event.Playing");
                     executeUpdate();
@@ -604,6 +611,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                         mMedialibrary.addToHistory(getCurrentMediaLocation(), getCurrentMediaWrapper().getTitle());
                     break;
                 case MediaPlayer.Event.Paused:
+                    mStopped = false;
                     Log.i(TAG, "MediaPlayer.Event.Paused");
                     executeUpdate();
                     publishState();
@@ -615,28 +623,14 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                     break;
                 case MediaPlayer.Event.Stopped:
                     Log.i(TAG, "MediaPlayer.Event.Stopped");
-                    saveMediaMeta();
-                    executeUpdate();
-                    publishState();
-                    executeUpdateProgress();
-                    if (mWakeLock.isHeld())
-                        mWakeLock.release();
-                    changeAudioFocus(false);
+                    onPlaybackStopped();
                     break;
                 case MediaPlayer.Event.EndReached:
                     saveMediaMeta();
                     executeUpdateProgress();
                     previousMediaStats = mMediaPlayer.getMedia().getStats();
                     determinePrevAndNextIndices(true);
-                    if (mNextIndex != -1) {
-                        next();
-                    } else {
-                        if (mWakeLock.isHeld())
-                            mWakeLock.release();
-                        changeAudioFocus(false);
-                        executeUpdate();
-                        publishState();
-                    }
+                    next();
                     break;
                 case MediaPlayer.Event.EncounteredError:
                     showToast(getString(
@@ -679,23 +673,37 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         }
     };
 
+    private void onPlaybackStopped() {
+        if (mStopped)
+            return;
+        mStopped = true;
+        mCurrentIndex = -1;
+        hideNotification();
+        executeUpdate();
+        publishState();
+        executeUpdateProgress();
+        if (mWakeLock.isHeld())
+            mWakeLock.release();
+        changeAudioFocus(false);
+    }
+
     private void showPlayer() {
         sendBroadcast(new Intent(AudioPlayerContainerActivity.ACTION_SHOW_PLAYER));
     }
 
     public void saveMediaMeta() {
-        MediaWrapper media = mMedialibrary.findMedia(getCurrentMediaWrapper());
+        final MediaWrapper media = mMedialibrary.findMedia(getCurrentMediaWrapper());
         if (media == null || media.getId() == 0)
             return;
-        boolean canSwitchToVideo = canSwitchToVideo();
+        final boolean canSwitchToVideo = canSwitchToVideo();
         if (canSwitchToVideo || media.isPodcast()) {
             //Save progress
-            long time = getTime();
+            final long time = getTime();
             float progress = time / (float)media.getLength();
-            if (progress > 0.90f) {
-                //increase seen counter if more than 90% of the media have been seen
+            if (progress > 0.95f) {
+                //increase seen counter if more than 95% of the media have been seen
                 //and reset progress to 0
-                long incSeen = media.getSeen() + 1L;
+                final long incSeen = media.getSeen() + 1L;
                 media.setLongMeta(MediaWrapper.META_SEEN, incSeen);
                 media.setSeen(incSeen);
                 progress = 0f;
@@ -713,7 +721,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     }
 
     private void loadMediaMeta() {
-        MediaWrapper media = mMedialibrary.findMedia(getCurrentMediaWrapper());
+        final MediaWrapper media = mMedialibrary.findMedia(getCurrentMediaWrapper());
         if (media == null || media.getId() == 0)
             return;
         if (canSwitchToVideo()) {
@@ -991,17 +999,11 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                 }
             });
             media.release();
-            publishState();
         }
         mMediaList.removeEventListener(mListEventListener);
-        mCurrentIndex = -1;
         mPrevious.clear();
         mHandler.removeMessages(SHOW_PROGRESS);
-        hideNotification();
-        broadcastMetadata();
-        executeUpdate();
-        executeUpdateProgress();
-        changeAudioFocus(false);
+        onPlaybackStopped();
     }
 
     private void determinePrevAndNextIndices() {
@@ -1129,7 +1131,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                             }
                             break;
                         case KeyEvent.ACTION_UP:
-                            if (AndroidDevices.hasTsp()) { //no backward/forward on TV
+                            if (AndroidDevices.hasTsp) { //no backward/forward on TV
                                 if (time - mHeadsetDownTime >= DELAY_LONG_CLICK) { // long click
                                     mHeadsetUpTime = time;
                                     previous(false);
@@ -1194,6 +1196,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                 load(mMedialibrary.getAlbum(Long.parseLong(mediaId.split("_")[1])).getTracks(), 0);
             } else if (mediaId.startsWith(BrowserProvider.PLAYLIST_PREFIX)) {
                 load(mMedialibrary.getPlaylist(Long.parseLong(mediaId.split("_")[1])).getTracks(), 0);
+            } else if (mediaId.startsWith(ExtensionsManager.EXTENSION_PREFIX)) {
+                onPlayFromUri(Uri.parse(mediaId.replace(ExtensionsManager.EXTENSION_PREFIX + "_" + mediaId.split("_")[1] + "_", "")), null);
             } else
                 try {
                     load(mMedialibrary.getMedia(Long.parseLong(mediaId)));
@@ -1346,15 +1350,16 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         });
     }
 
+    private volatile boolean mStopped = true;
     protected void publishState() {
         if (mMediaSession == null)
             return;
         PlaybackStateCompat.Builder pscb = new PlaybackStateCompat.Builder();
         long actions = PLAYBACK_BASE_ACTIONS;
-        if (isPlaying()) {
+        if (!mStopped && isPlaying()) {
             actions |= PlaybackStateCompat.ACTION_PAUSE | PlaybackStateCompat.ACTION_STOP;
             pscb.setState(PlaybackStateCompat.STATE_PLAYING, getTime(), getRate());
-        } else if (hasMedia()) {
+        } else if (!mStopped && hasMedia()) {
             actions |= PlaybackStateCompat.ACTION_PLAY | PlaybackStateCompat.ACTION_STOP;
             pscb.setState(PlaybackStateCompat.STATE_PAUSED, getTime(), getRate());
         } else {
