@@ -120,7 +120,7 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
         mBottomSheetBehavior = BottomSheetBehavior.from(mAudioPlayerContainer);
         mBottomSheetBehavior.setPeekHeight(getResources().getDimensionPixelSize(R.dimen.player_peek_height));
         mBottomSheetBehavior.setBottomSheetCallback(mAudioPlayerBottomSheetCallback);
-        mAudioPlayer.showAudioPlayerTips();
+        showTipViewIfNeeded(R.id.audio_player_tips, AudioPlayer.PREF_AUDIOPLAYER_TIPS_SHOWN);
     }
 
     @Override
