@@ -72,16 +72,16 @@ import java.util.Random;
 public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefreshLayout.OnRefreshListener, ViewPager.OnPageChangeListener, Medialibrary.ArtistsAddedCb, Medialibrary.ArtistsModifiedCb, Medialibrary.AlbumsAddedCb, Medialibrary.AlbumsModifiedCb, MediaAddedCb, MediaUpdatedCb, TabLayout.OnTabSelectedListener {
     public final static String TAG = "VLC/AudioBrowserFragment";
 
-    private AudioBrowserAdapter mArtistsAdapter;
-    private AudioBrowserAdapter mAlbumsAdapter;
-    private AudioBrowserAdapter mSongsAdapter;
-    private AudioBrowserAdapter mGenresAdapter;
-    private AudioBrowserAdapter mPlaylistAdapter;
+    private final AudioBrowserAdapter mSongsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_MEDIA, this, true);
+    private final AudioBrowserAdapter mArtistsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ARTIST, this, true);
+    private final AudioBrowserAdapter mAlbumsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ALBUM, this, true);
+    private final AudioBrowserAdapter mGenresAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_GENRE, this, true);
+    private final AudioBrowserAdapter mPlaylistAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_PLAYLIST, this, true);
 
     private ViewPager mViewPager;
     private TabLayout mTabLayout;
     private TextView mEmptyView;
-    private ContextMenuRecyclerView[] mLists;
+    private final ContextMenuRecyclerView[] mLists = new ContextMenuRecyclerView[MODE_TOTAL];
     private FastScroller mFastScroller;
 
     public static final int REFRESH = 101;
@@ -100,6 +100,12 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
 
     public final static String TAG_ITEM = "ML_ITEM";
 
+    @Override
+    public void onCreate(Bundle savedInstanceState) {
+        super.onCreate(savedInstanceState);
+        mAdapters = new AudioBrowserAdapter[]{mArtistsAdapter, mAlbumsAdapter, mSongsAdapter, mGenresAdapter, mPlaylistAdapter};
+    }
+
     @Override
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
         return inflater.inflate(R.layout.audio_browser, container, false);
@@ -119,13 +125,6 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
     @Override
     public void onActivityCreated(@Nullable Bundle savedInstanceState) {
         super.onActivityCreated(savedInstanceState);
-        mSongsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_MEDIA, this, true);
-        mArtistsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ARTIST, this, true);
-        mAlbumsAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_ALBUM, this, true);
-        mGenresAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_GENRE, this, true);
-        mPlaylistAdapter = new AudioBrowserAdapter(getActivity(), MediaLibraryItem.TYPE_PLAYLIST, this, true);
-        mAdapters = new AudioBrowserAdapter[]{mArtistsAdapter, mAlbumsAdapter, mSongsAdapter, mGenresAdapter, mPlaylistAdapter};
-        mLists = new ContextMenuRecyclerView[MODE_TOTAL];
         for (int i = 0; i < MODE_TOTAL; i++)
             mLists[i] = (ContextMenuRecyclerView) mViewPager.getChildAt(i);
 
@@ -151,36 +150,28 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         mSwipeRefreshLayout.setOnRefreshListener(this);
     }
 
-    public void onStart() {
-        if (mMediaLibrary.isInitiated())
-            onMedialibraryReady();
-        else
-            setupMediaLibraryReceiver();
-        super.onStart();
-        for (View rv : mLists)
-            registerForContextMenu(rv);
-        mViewPager.addOnPageChangeListener(this);
-    }
-
     @Override
     public void onHiddenChanged(boolean hidden) {
         super.onHiddenChanged(hidden);
         if (!hidden) {
+            if (mMediaLibrary.isInitiated())
+                onMedialibraryReady();
+            else
+                setupMediaLibraryReceiver();
+            for (View rv : mLists)
+                registerForContextMenu(rv);
+            mViewPager.addOnPageChangeListener(this);
             mFabPlay.setImageResource(R.drawable.ic_fab_shuffle);
             setFabPlayShuffleAllVisibility();
+        } else {
+            mMediaLibrary.removeMediaUpdatedCb();
+            mMediaLibrary.removeMediaAddedCb();
+            for (View rv : mLists)
+                unregisterForContextMenu(rv);
+            mViewPager.removeOnPageChangeListener(this);
         }
     }
 
-    @Override
-    public void onStop() {
-        super.onStop();
-        mMediaLibrary.removeMediaUpdatedCb();
-        mMediaLibrary.removeMediaAddedCb();
-        for (View rv : mLists)
-            unregisterForContextMenu(rv);
-        mViewPager.removeOnPageChangeListener(this);
-    }
-
     private void setupTabLayout() {
         mTabLayout.setupWithViewPager(mViewPager);
         mViewPager.addOnPageChangeListener(new TabLayout.TabLayoutOnPageChangeListener(mTabLayout));
@@ -235,7 +226,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
                 item.setVisible(FileUtils.canWrite(location));
             }
         }
-        if (!AndroidDevices.isPhone())
+        if (!AndroidDevices.isPhone)
             menu.setGroupVisible(R.id.phone_only, false);
     }
 
