@@ -85,7 +85,6 @@ import java.util.LinkedList;
 public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAdapter> implements IRefreshable, MediaBrowser.EventListener, SwipeRefreshLayout.OnRefreshListener, View.OnClickListener, Filterable, IEventsHandler {
     protected static final String TAG = "VLC/BaseBrowserFragment";
 
-    public static String ROOT = "smb";
     public static final String KEY_MRL = "key_mrl";
     public static final String KEY_MEDIA = "key_media";
     public static final String KEY_MEDIA_LIST = "key_media_list";
@@ -150,6 +149,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
             mMrl = getActivity().getIntent().getDataString();
             getActivity().setIntent(null);
         }
+        mRoot = defineIsRoot();
         if (mFoldersContentLists == null)
             mFoldersContentLists = new SimpleArrayMap<>();
     }
@@ -164,6 +164,10 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
         return R.layout.directory_browser;
     }
 
+    protected boolean defineIsRoot() {
+        return mMrl == null;
+    }
+
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
         return inflater.inflate(getLayoutId(), container, false);
     }
@@ -208,29 +212,19 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     @Override
     public void onHiddenChanged(boolean hidden) {
         super.onHiddenChanged(hidden);
-        if (mRoot) {
+        if (hidden || mRoot) {
             runOnBrowserThread(new Runnable() {
                 @Override
                 public void run() {
                     releaseBrowser();
                 }
             });
-        } else if (!hidden && mFabPlay != null) {
+        } else if (mFabPlay != null) {
             mFabPlay.setImageResource(R.drawable.ic_fab_play);
             updateFab();
         }
     }
 
-    public void onStop(){
-        super.onStop();
-        runOnBrowserThread(new Runnable() {
-            @Override
-            public void run() {
-                releaseBrowser();
-            }
-        });
-    }
-
     private void releaseBrowser() {
         if (mMediaBrowser != null) {
             mMediaBrowser.release();
@@ -764,7 +758,8 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     }
 
     public void restoreList() {
-        mAdapter.restoreList();
+        if (mAdapter != null)
+            mAdapter.restoreList();
     }
     public void setSearchVisibility(boolean visible) {
         UiTools.setViewVisibility(mSearchButtonView, visible ? View.VISIBLE : View.GONE);
