@@ -75,7 +75,6 @@ import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCInstance;
 
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.List;
 
 public class VideoGridFragment extends SortableFragment<VideoListAdapter> implements MediaUpdatedCb, SwipeRefreshLayout.OnRefreshListener, MediaAddedCb, Filterable, IEventsHandler {
@@ -98,6 +97,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     @Override
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
+        mAdapter = new VideoListAdapter(this);
 
         if (savedInstanceState != null)
             setGroup(savedInstanceState.getString(KEY_GROUP));
@@ -146,7 +146,6 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
         super.onActivityCreated(savedInstanceState);
         mSwipeRefreshLayout.setOnRefreshListener(this);
         mDividerItemDecoration = new DividerItemDecoration(getActivity(), DividerItemDecoration.VERTICAL);
-        mAdapter = new VideoListAdapter(this);
         if (mAdapter.isListMode())
             mGridView.addItemDecoration(mDividerItemDecoration);
         if (savedInstanceState != null) {
@@ -157,34 +156,26 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
         mGridView.setAdapter(mAdapter);
     }
 
-    public void onStart() {
-        if (mMediaLibrary.isInitiated())
-            onMedialibraryReady();
-        else if (mGroup == null)
-            setupMediaLibraryReceiver();
-        super.onStart();
-        registerForContextMenu(mGridView);
-    }
-
     @Override
     public void onHiddenChanged(boolean hidden) {
         super.onHiddenChanged(hidden);
         if (!hidden) {
+            if (mMediaLibrary.isInitiated())
+                onMedialibraryReady();
+            else if (mGroup == null)
+                setupMediaLibraryReceiver();
+            registerForContextMenu(mGridView);
             setSearchVisibility(false);
             updateViewMode();
             mFabPlay.setImageResource(R.drawable.ic_fab_play);
             setFabPlayVisibility(true);
+        } else {
+            mMediaLibrary.removeMediaUpdatedCb();
+            mMediaLibrary.removeMediaAddedCb();
+            unregisterForContextMenu(mGridView);
         }
     }
 
-    @Override
-    public void onStop() {
-        super.onStop();
-        mMediaLibrary.removeMediaUpdatedCb();
-        mMediaLibrary.removeMediaAddedCb();
-        unregisterForContextMenu(mGridView);
-    }
-
     @Override
     public void onSaveInstanceState(Bundle outState) {
         super.onSaveInstanceState(outState);
@@ -198,7 +189,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
             mMediaLibrary.setMediaUpdatedCb(this, Medialibrary.FLAG_MEDIA_UPDATED_VIDEO);
             mMediaLibrary.setMediaAddedCb(this, Medialibrary.FLAG_MEDIA_ADDED_VIDEO);
         }
-        if (!isHidden() && mAdapter.isEmpty())
+        if (!isHidden())
             mHandler.sendEmptyMessage(UPDATE_LIST);
     }
 
@@ -439,7 +430,8 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
 
     @Override
     public void restoreList() {
-        mAdapter.restoreList();
+        if (mAdapter != null)
+            mAdapter.restoreList();
     }
 
     @Override
