@@ -202,8 +202,8 @@ public class VLCOptions {
     @MainThread
     public static MediaPlayer.Equalizer getEqualizerSetFromSettings(Context context) {
         final SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(context);
-        if (pref.getBoolean("equalizer_enabled", false)) {
-            final float[] bands = Preferences.getFloatArray(pref, "equalizer_values");
+        final float[] bands = Preferences.getFloatArray(pref, "equalizer_values");
+        if (bands != null && pref.contains("equalizer_enabled")) {
             final int bandCount = MediaPlayer.Equalizer.getBandCount();
             if (bands.length != bandCount + 1)
                 return null;
@@ -214,7 +214,7 @@ public class VLCOptions {
                 eq.setAmp(i, bands[i + 1]);
             return eq;
         } else
-            return null;
+            return MediaPlayer.Equalizer.createFromPreset(0);
     }
 
     @MainThread
@@ -224,11 +224,11 @@ public class VLCOptions {
     }
 
     @MainThread
-    public static void saveEqualizerInSettings(Context context, MediaPlayer.Equalizer eq, String name) {
+    public static void saveEqualizerInSettings(Context context, MediaPlayer.Equalizer eq, String name, boolean enabled, boolean saved) {
         final SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(context);
         SharedPreferences.Editor editor = pref.edit();
         if (eq != null) {
-            editor.putBoolean("equalizer_enabled", true);
+            editor.putBoolean("equalizer_enabled", enabled);
             final int bandCount = MediaPlayer.Equalizer.getBandCount();
             final float[] bands = new float[bandCount + 1];
             bands[0] = eq.getPreAmp();
@@ -240,6 +240,7 @@ public class VLCOptions {
         } else {
             editor.putBoolean("equalizer_enabled", false);
         }
+        editor.putBoolean("equalizer_saved", saved);
         editor.apply();
     }
 
@@ -286,4 +287,14 @@ public class VLCOptions {
                 .remove("custom_equalizer_" + customName.replace(" ", "_"))
                 .apply();
     }
+
+    public static boolean getEqualizerSavedState (Context context){
+        return PreferenceManager.getDefaultSharedPreferences(context)
+                .getBoolean("equalizer_saved", true);
+    }
+
+    public static boolean getEqualizerEnabledState (Context context){
+        return PreferenceManager.getDefaultSharedPreferences(context)
+                .getBoolean("equalizer_enabled", false);
+    }
 }
